==> nextcloud-20.0.10.tgz: nextcloud/apps/notifications/l10n/he.js <==
OC.L10N.register(
    "notifications",
    {
    "Admin notifications" : "התרעות למנהלים",
    "Notifications" : "התרעות",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "יישומון זה מספק מנגנון ומנשק משתמש ל־API של ההתראות שזמין ב־Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "יישום זה מספק backend ו- frontend עבור ממשק ה-API להודעות הזמין ב- Nextcloud.\nה-API משמש אפליקציות אחרות כדי להודיע למשתמשים בממשק המשתמש באינטרנט ולסנכרן לקוחות על דברים שונים. חלק מהדוגמאות הן:\n\n📬 שיתוף קבצים מאוחד: קיבלתם שיתוף מרוחק חדש\n\n📑 הערות: משתמש אחר הזכיר אותך בתגובה לקובץ\n\n🚢 הודעת עדכון: עדכון זמין לאפליקציה או ל- Nextcloud עצמו\n\n📣 מרכז הודעות: הודעה פורסמה על ידי מנהל המערכת",
    "Dismiss all notifications" : "התעלמות מכל ההתראות",
    "Requesting browser permissions to show notifications" : "מתבצעת בקשה מול הדפדפן להציג התראות",
    "No notifications" : "אין התרעות",
    "Failed to dismiss all notifications" : "התעלמות מכל ההתרעות נכשלה",
    "Failed to perform action" : "הפעולה נכשלה",
    "Dismiss" : "התעלמות",
    "seconds ago" : "לפני מספר שניות",
    "Failed to dismiss notification" : "ההתעלמות מההתרעה נכשלה",
    "in {path}" : "תחת {path}"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");

==> nextcloud-22.2.10.tgz: nextcloud/apps/notifications/l10n/he.js <==
OC.L10N.register(
    "notifications",
    {
    "Hello %s" : "שלום %s",
    "Hello %s," : "שלום %s,",
    "Admin notifications" : "התרעות למנהלים",
    "Notifications" : "התרעות",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "יישומון זה מספק מנגנון ומנשק משתמש ל־API של ההתראות שזמין ב־Nextcloud.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "יישום זה מספק backend ו- frontend עבור ממשק ה-API להודעות הזמין ב- Nextcloud.\nה-API משמש אפליקציות אחרות כדי להודיע למשתמשים בממשק המשתמש באינטרנט ולסנכרן לקוחות על דברים שונים. חלק מהדוגמאות הן:\n\n📬 שיתוף קבצים מאוחד: קיבלתם שיתוף מרוחק חדש\n\n📑 הערות: משתמש אחר הזכיר אותך בתגובה לקובץ\n\n🚢 הודעת עדכון: עדכון זמין לאפליקציה או ל- Nextcloud עצמו\n\n📣 מרכז הודעות: הודעה פורסמה על ידי מנהל המערכת",
    "Failed to perform action" : "הפעולה נכשלה",
    "Dismiss" : "התעלמות",
    "seconds ago" : "לפני מספר שניות",
    "Failed to dismiss notification" : "ההתעלמות מההתרעה נכשלה",
    "in {path}" : "תחת {path}",
    "Dismiss all notifications" : "התעלמות מכל ההתראות",
    "Requesting browser permissions to show notifications" : "מתבצעת בקשה מול הדפדפן להציג התראות",
    "No notifications" : "אין התרעות",
    "Failed to dismiss all notifications" : "התעלמות מכל ההתרעות נכשלה",
    "You need to set up your email address before you can receive notification emails." : "יש להגדיר כתובת דואר אלקטרוני לפני שניתן יהיה לקבל דיווחים.",
    "Never" : "מעולם לא",
    "1 hour" : "שעה",
    "3 hours" : "3 שעות",
    "1 day" : "יום",
    "Your settings have been updated." : "ההגדרות שלך עודכנו"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
